# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 deployment_id: pulumi.Input[_builtins.str],
                 password: pulumi.Input[_builtins.str],
                 is_admin: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[_builtins.str] deployment_id: ID of the Data Warehouse deployment to which this user belongs.
        :param pulumi.Input[_builtins.str] password: Password for the ClickHouse user.
        :param pulumi.Input[_builtins.bool] is_admin: Whether the user has administrator privileges. Defaults to `false`.
        :param pulumi.Input[_builtins.str] name: Name of the ClickHouse user.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the user should be created.
        """
        pulumi.set(__self__, "deployment_id", deployment_id)
        pulumi.set(__self__, "password", password)
        if is_admin is not None:
            pulumi.set(__self__, "is_admin", is_admin)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the Data Warehouse deployment to which this user belongs.
        """
        return pulumi.get(self, "deployment_id")

    @deployment_id.setter
    def deployment_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "deployment_id", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Input[_builtins.str]:
        """
        Password for the ClickHouse user.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter(name="isAdmin")
    def is_admin(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the user has administrator privileges. Defaults to `false`.
        """
        return pulumi.get(self, "is_admin")

    @is_admin.setter
    def is_admin(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_admin", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the ClickHouse user.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the user should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 deployment_id: Optional[pulumi.Input[_builtins.str]] = None,
                 is_admin: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[_builtins.str] deployment_id: ID of the Data Warehouse deployment to which this user belongs.
        :param pulumi.Input[_builtins.bool] is_admin: Whether the user has administrator privileges. Defaults to `false`.
        :param pulumi.Input[_builtins.str] name: Name of the ClickHouse user.
        :param pulumi.Input[_builtins.str] password: Password for the ClickHouse user.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the user should be created.
        """
        if deployment_id is not None:
            pulumi.set(__self__, "deployment_id", deployment_id)
        if is_admin is not None:
            pulumi.set(__self__, "is_admin", is_admin)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the Data Warehouse deployment to which this user belongs.
        """
        return pulumi.get(self, "deployment_id")

    @deployment_id.setter
    def deployment_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "deployment_id", value)

    @_builtins.property
    @pulumi.getter(name="isAdmin")
    def is_admin(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the user has administrator privileges. Defaults to `false`.
        """
        return pulumi.get(self, "is_admin")

    @is_admin.setter
    def is_admin(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_admin", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the ClickHouse user.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for the ClickHouse user.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the user should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.type_token("scaleway:datawarehouse/user:User")
class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deployment_id: Optional[pulumi.Input[_builtins.str]] = None,
                 is_admin: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Data Warehouse users within a deployment.
        For more information refer to the [product documentation](https://www.scaleway.com/en/docs/data-warehouse/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.datawarehouse.Deployment("main",
            name="my-datawarehouse",
            version="v25",
            replica_count=1,
            cpu_min=2,
            cpu_max=4,
            ram_per_cpu=4,
            password="thiZ_is_v&ry_s3cret")
        main_user = scaleway.datawarehouse.User("main",
            deployment_id=main.id,
            name="my_user",
            password="user_password_123")
        ```

        ### Admin User

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.datawarehouse.Deployment("main",
            name="my-datawarehouse",
            version="v25",
            replica_count=1,
            cpu_min=2,
            cpu_max=4,
            ram_per_cpu=4,
            password="thiZ_is_v&ry_s3cret")
        admin = scaleway.datawarehouse.User("admin",
            deployment_id=main.id,
            name="admin_user",
            password="admin_password_456",
            is_admin=True)
        ```

        ## Import

        Data Warehouse users can be imported using the `{region}/{deployment_id}/{name}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:datawarehouse/user:User main fr-par/11111111-1111-1111-1111-111111111111/my_user
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] deployment_id: ID of the Data Warehouse deployment to which this user belongs.
        :param pulumi.Input[_builtins.bool] is_admin: Whether the user has administrator privileges. Defaults to `false`.
        :param pulumi.Input[_builtins.str] name: Name of the ClickHouse user.
        :param pulumi.Input[_builtins.str] password: Password for the ClickHouse user.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the user should be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Data Warehouse users within a deployment.
        For more information refer to the [product documentation](https://www.scaleway.com/en/docs/data-warehouse/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.datawarehouse.Deployment("main",
            name="my-datawarehouse",
            version="v25",
            replica_count=1,
            cpu_min=2,
            cpu_max=4,
            ram_per_cpu=4,
            password="thiZ_is_v&ry_s3cret")
        main_user = scaleway.datawarehouse.User("main",
            deployment_id=main.id,
            name="my_user",
            password="user_password_123")
        ```

        ### Admin User

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.datawarehouse.Deployment("main",
            name="my-datawarehouse",
            version="v25",
            replica_count=1,
            cpu_min=2,
            cpu_max=4,
            ram_per_cpu=4,
            password="thiZ_is_v&ry_s3cret")
        admin = scaleway.datawarehouse.User("admin",
            deployment_id=main.id,
            name="admin_user",
            password="admin_password_456",
            is_admin=True)
        ```

        ## Import

        Data Warehouse users can be imported using the `{region}/{deployment_id}/{name}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:datawarehouse/user:User main fr-par/11111111-1111-1111-1111-111111111111/my_user
        ```

        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deployment_id: Optional[pulumi.Input[_builtins.str]] = None,
                 is_admin: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            if deployment_id is None and not opts.urn:
                raise TypeError("Missing required property 'deployment_id'")
            __props__.__dict__["deployment_id"] = deployment_id
            __props__.__dict__["is_admin"] = is_admin
            __props__.__dict__["name"] = name
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["region"] = region
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(User, __self__).__init__(
            'scaleway:datawarehouse/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            deployment_id: Optional[pulumi.Input[_builtins.str]] = None,
            is_admin: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            password: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] deployment_id: ID of the Data Warehouse deployment to which this user belongs.
        :param pulumi.Input[_builtins.bool] is_admin: Whether the user has administrator privileges. Defaults to `false`.
        :param pulumi.Input[_builtins.str] name: Name of the ClickHouse user.
        :param pulumi.Input[_builtins.str] password: Password for the ClickHouse user.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the user should be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["deployment_id"] = deployment_id
        __props__.__dict__["is_admin"] = is_admin
        __props__.__dict__["name"] = name
        __props__.__dict__["password"] = password
        __props__.__dict__["region"] = region
        return User(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the Data Warehouse deployment to which this user belongs.
        """
        return pulumi.get(self, "deployment_id")

    @_builtins.property
    @pulumi.getter(name="isAdmin")
    def is_admin(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the user has administrator privileges. Defaults to `false`.
        """
        return pulumi.get(self, "is_admin")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the ClickHouse user.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Output[_builtins.str]:
        """
        Password for the ClickHouse user.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region in which the user should be created.
        """
        return pulumi.get(self, "region")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetConfigResult',
    'AwaitableGetConfigResult',
    'get_config',
    'get_config_output',
]

@pulumi.output_type
class GetConfigResult:
    """
    A collection of values returned by getConfig.
    """
    def __init__(__self__, access_key=None, access_key_source=None, id=None, organization_id=None, organization_id_source=None, project_id=None, project_id_source=None, region=None, region_source=None, secret_key=None, secret_key_source=None, zone=None, zone_source=None):
        if access_key and not isinstance(access_key, str):
            raise TypeError("Expected argument 'access_key' to be a str")
        pulumi.set(__self__, "access_key", access_key)
        if access_key_source and not isinstance(access_key_source, str):
            raise TypeError("Expected argument 'access_key_source' to be a str")
        pulumi.set(__self__, "access_key_source", access_key_source)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if organization_id_source and not isinstance(organization_id_source, str):
            raise TypeError("Expected argument 'organization_id_source' to be a str")
        pulumi.set(__self__, "organization_id_source", organization_id_source)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if project_id_source and not isinstance(project_id_source, str):
            raise TypeError("Expected argument 'project_id_source' to be a str")
        pulumi.set(__self__, "project_id_source", project_id_source)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if region_source and not isinstance(region_source, str):
            raise TypeError("Expected argument 'region_source' to be a str")
        pulumi.set(__self__, "region_source", region_source)
        if secret_key and not isinstance(secret_key, str):
            raise TypeError("Expected argument 'secret_key' to be a str")
        pulumi.set(__self__, "secret_key", secret_key)
        if secret_key_source and not isinstance(secret_key_source, str):
            raise TypeError("Expected argument 'secret_key_source' to be a str")
        pulumi.set(__self__, "secret_key_source", secret_key_source)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)
        if zone_source and not isinstance(zone_source, str):
            raise TypeError("Expected argument 'zone_source' to be a str")
        pulumi.set(__self__, "zone_source", zone_source)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> _builtins.str:
        return pulumi.get(self, "access_key")

    @_builtins.property
    @pulumi.getter(name="accessKeySource")
    def access_key_source(self) -> _builtins.str:
        return pulumi.get(self, "access_key_source")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="organizationIdSource")
    def organization_id_source(self) -> _builtins.str:
        return pulumi.get(self, "organization_id_source")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="projectIdSource")
    def project_id_source(self) -> _builtins.str:
        return pulumi.get(self, "project_id_source")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="regionSource")
    def region_source(self) -> _builtins.str:
        return pulumi.get(self, "region_source")

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> _builtins.str:
        return pulumi.get(self, "secret_key")

    @_builtins.property
    @pulumi.getter(name="secretKeySource")
    def secret_key_source(self) -> _builtins.str:
        return pulumi.get(self, "secret_key_source")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> _builtins.str:
        return pulumi.get(self, "zone")

    @_builtins.property
    @pulumi.getter(name="zoneSource")
    def zone_source(self) -> _builtins.str:
        return pulumi.get(self, "zone_source")


class AwaitableGetConfigResult(GetConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetConfigResult(
            access_key=self.access_key,
            access_key_source=self.access_key_source,
            id=self.id,
            organization_id=self.organization_id,
            organization_id_source=self.organization_id_source,
            project_id=self.project_id,
            project_id_source=self.project_id_source,
            region=self.region,
            region_source=self.region_source,
            secret_key=self.secret_key,
            secret_key_source=self.secret_key_source,
            zone=self.zone,
            zone_source=self.zone_source)


def get_config(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetConfigResult:
    """
    Gets information about the current configuration that Scaleway provider is using.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get configuration information
    main = scaleway.get_config()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:index/getConfig:getConfig', __args__, opts=opts, typ=GetConfigResult).value

    return AwaitableGetConfigResult(
        access_key=pulumi.get(__ret__, 'access_key'),
        access_key_source=pulumi.get(__ret__, 'access_key_source'),
        id=pulumi.get(__ret__, 'id'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        organization_id_source=pulumi.get(__ret__, 'organization_id_source'),
        project_id=pulumi.get(__ret__, 'project_id'),
        project_id_source=pulumi.get(__ret__, 'project_id_source'),
        region=pulumi.get(__ret__, 'region'),
        region_source=pulumi.get(__ret__, 'region_source'),
        secret_key=pulumi.get(__ret__, 'secret_key'),
        secret_key_source=pulumi.get(__ret__, 'secret_key_source'),
        zone=pulumi.get(__ret__, 'zone'),
        zone_source=pulumi.get(__ret__, 'zone_source'))
def get_config_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetConfigResult]:
    """
    Gets information about the current configuration that Scaleway provider is using.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get configuration information
    main = scaleway.get_config()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:index/getConfig:getConfig', __args__, opts=opts, typ=GetConfigResult)
    return __ret__.apply(lambda __response__: GetConfigResult(
        access_key=pulumi.get(__response__, 'access_key'),
        access_key_source=pulumi.get(__response__, 'access_key_source'),
        id=pulumi.get(__response__, 'id'),
        organization_id=pulumi.get(__response__, 'organization_id'),
        organization_id_source=pulumi.get(__response__, 'organization_id_source'),
        project_id=pulumi.get(__response__, 'project_id'),
        project_id_source=pulumi.get(__response__, 'project_id_source'),
        region=pulumi.get(__response__, 'region'),
        region_source=pulumi.get(__response__, 'region_source'),
        secret_key=pulumi.get(__response__, 'secret_key'),
        secret_key_source=pulumi.get(__response__, 'secret_key_source'),
        zone=pulumi.get(__response__, 'zone'),
        zone_source=pulumi.get(__response__, 'zone_source')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EdgeServicesCacheStageArgs', 'EdgeServicesCacheStage']

@pulumi.input_type
class EdgeServicesCacheStageArgs:
    def __init__(__self__, *,
                 pipeline_id: pulumi.Input[_builtins.str],
                 backend_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 fallback_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 include_cookies: Optional[pulumi.Input[_builtins.bool]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 purge_requests: Optional[pulumi.Input[Sequence[pulumi.Input['EdgeServicesCacheStagePurgeRequestArgs']]]] = None,
                 refresh_cache: Optional[pulumi.Input[_builtins.str]] = None,
                 route_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 waf_stage_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a EdgeServicesCacheStage resource.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        :param pulumi.Input[_builtins.str] backend_stage_id: The backend stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        :param pulumi.Input[_builtins.int] fallback_ttl: The Time To Live (TTL) in seconds. Defines how long content is cached.
        :param pulumi.Input[_builtins.bool] include_cookies: Defines whether responses to requests with cookies must be stored in the cache.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cache stage is associated with.
        :param pulumi.Input[Sequence[pulumi.Input['EdgeServicesCacheStagePurgeRequestArgs']]] purge_requests: The Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        :param pulumi.Input[_builtins.str] refresh_cache: Trigger a refresh of the cache by changing this field's value.
        :param pulumi.Input[_builtins.str] route_stage_id: The route stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        :param pulumi.Input[_builtins.str] waf_stage_id: The WAF stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        """
        pulumi.set(__self__, "pipeline_id", pipeline_id)
        if backend_stage_id is not None:
            pulumi.set(__self__, "backend_stage_id", backend_stage_id)
        if fallback_ttl is not None:
            pulumi.set(__self__, "fallback_ttl", fallback_ttl)
        if include_cookies is not None:
            pulumi.set(__self__, "include_cookies", include_cookies)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if purge_requests is not None:
            pulumi.set(__self__, "purge_requests", purge_requests)
        if refresh_cache is not None:
            pulumi.set(__self__, "refresh_cache", refresh_cache)
        if route_stage_id is not None:
            pulumi.set(__self__, "route_stage_id", route_stage_id)
        if waf_stage_id is not None:
            pulumi.set(__self__, "waf_stage_id", waf_stage_id)

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")

    @pipeline_id.setter
    def pipeline_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "pipeline_id", value)

    @_builtins.property
    @pulumi.getter(name="backendStageId")
    def backend_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The backend stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        """
        return pulumi.get(self, "backend_stage_id")

    @backend_stage_id.setter
    def backend_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "backend_stage_id", value)

    @_builtins.property
    @pulumi.getter(name="fallbackTtl")
    def fallback_ttl(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The Time To Live (TTL) in seconds. Defines how long content is cached.
        """
        return pulumi.get(self, "fallback_ttl")

    @fallback_ttl.setter
    def fallback_ttl(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "fallback_ttl", value)

    @_builtins.property
    @pulumi.getter(name="includeCookies")
    def include_cookies(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defines whether responses to requests with cookies must be stored in the cache.
        """
        return pulumi.get(self, "include_cookies")

    @include_cookies.setter
    def include_cookies(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "include_cookies", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the cache stage is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="purgeRequests")
    def purge_requests(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EdgeServicesCacheStagePurgeRequestArgs']]]]:
        """
        The Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        """
        return pulumi.get(self, "purge_requests")

    @purge_requests.setter
    def purge_requests(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EdgeServicesCacheStagePurgeRequestArgs']]]]):
        pulumi.set(self, "purge_requests", value)

    @_builtins.property
    @pulumi.getter(name="refreshCache")
    def refresh_cache(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Trigger a refresh of the cache by changing this field's value.
        """
        return pulumi.get(self, "refresh_cache")

    @refresh_cache.setter
    def refresh_cache(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "refresh_cache", value)

    @_builtins.property
    @pulumi.getter(name="routeStageId")
    def route_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The route stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        """
        return pulumi.get(self, "route_stage_id")

    @route_stage_id.setter
    def route_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "route_stage_id", value)

    @_builtins.property
    @pulumi.getter(name="wafStageId")
    def waf_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The WAF stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        """
        return pulumi.get(self, "waf_stage_id")

    @waf_stage_id.setter
    def waf_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "waf_stage_id", value)


@pulumi.input_type
class _EdgeServicesCacheStageState:
    def __init__(__self__, *,
                 backend_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 fallback_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 include_cookies: Optional[pulumi.Input[_builtins.bool]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 purge_requests: Optional[pulumi.Input[Sequence[pulumi.Input['EdgeServicesCacheStagePurgeRequestArgs']]]] = None,
                 refresh_cache: Optional[pulumi.Input[_builtins.str]] = None,
                 route_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 waf_stage_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EdgeServicesCacheStage resources.
        :param pulumi.Input[_builtins.str] backend_stage_id: The backend stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the cache stage.
        :param pulumi.Input[_builtins.int] fallback_ttl: The Time To Live (TTL) in seconds. Defines how long content is cached.
        :param pulumi.Input[_builtins.bool] include_cookies: Defines whether responses to requests with cookies must be stored in the cache.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cache stage is associated with.
        :param pulumi.Input[Sequence[pulumi.Input['EdgeServicesCacheStagePurgeRequestArgs']]] purge_requests: The Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        :param pulumi.Input[_builtins.str] refresh_cache: Trigger a refresh of the cache by changing this field's value.
        :param pulumi.Input[_builtins.str] route_stage_id: The route stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the cache stage.
        :param pulumi.Input[_builtins.str] waf_stage_id: The WAF stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        """
        if backend_stage_id is not None:
            pulumi.set(__self__, "backend_stage_id", backend_stage_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if fallback_ttl is not None:
            pulumi.set(__self__, "fallback_ttl", fallback_ttl)
        if include_cookies is not None:
            pulumi.set(__self__, "include_cookies", include_cookies)
        if pipeline_id is not None:
            pulumi.set(__self__, "pipeline_id", pipeline_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if purge_requests is not None:
            pulumi.set(__self__, "purge_requests", purge_requests)
        if refresh_cache is not None:
            pulumi.set(__self__, "refresh_cache", refresh_cache)
        if route_stage_id is not None:
            pulumi.set(__self__, "route_stage_id", route_stage_id)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if waf_stage_id is not None:
            pulumi.set(__self__, "waf_stage_id", waf_stage_id)

    @_builtins.property
    @pulumi.getter(name="backendStageId")
    def backend_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The backend stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        """
        return pulumi.get(self, "backend_stage_id")

    @backend_stage_id.setter
    def backend_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "backend_stage_id", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the creation of the cache stage.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="fallbackTtl")
    def fallback_ttl(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The Time To Live (TTL) in seconds. Defines how long content is cached.
        """
        return pulumi.get(self, "fallback_ttl")

    @fallback_ttl.setter
    def fallback_ttl(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "fallback_ttl", value)

    @_builtins.property
    @pulumi.getter(name="includeCookies")
    def include_cookies(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defines whether responses to requests with cookies must be stored in the cache.
        """
        return pulumi.get(self, "include_cookies")

    @include_cookies.setter
    def include_cookies(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "include_cookies", value)

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")

    @pipeline_id.setter
    def pipeline_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pipeline_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the cache stage is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="purgeRequests")
    def purge_requests(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EdgeServicesCacheStagePurgeRequestArgs']]]]:
        """
        The Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        """
        return pulumi.get(self, "purge_requests")

    @purge_requests.setter
    def purge_requests(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EdgeServicesCacheStagePurgeRequestArgs']]]]):
        pulumi.set(self, "purge_requests", value)

    @_builtins.property
    @pulumi.getter(name="refreshCache")
    def refresh_cache(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Trigger a refresh of the cache by changing this field's value.
        """
        return pulumi.get(self, "refresh_cache")

    @refresh_cache.setter
    def refresh_cache(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "refresh_cache", value)

    @_builtins.property
    @pulumi.getter(name="routeStageId")
    def route_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The route stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        """
        return pulumi.get(self, "route_stage_id")

    @route_stage_id.setter
    def route_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "route_stage_id", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update of the cache stage.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="wafStageId")
    def waf_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The WAF stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        """
        return pulumi.get(self, "waf_stage_id")

    @waf_stage_id.setter
    def waf_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "waf_stage_id", value)


warnings.warn("""scaleway.index/edgeservicescachestage.EdgeServicesCacheStage has been deprecated in favor of scaleway.edgeservices/cachestage.CacheStage""", DeprecationWarning)


@pulumi.type_token("scaleway:index/edgeServicesCacheStage:EdgeServicesCacheStage")
class EdgeServicesCacheStage(pulumi.CustomResource):
    warnings.warn("""scaleway.index/edgeservicescachestage.EdgeServicesCacheStage has been deprecated in favor of scaleway.edgeservices/cachestage.CacheStage""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 fallback_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 include_cookies: Optional[pulumi.Input[_builtins.bool]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 purge_requests: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EdgeServicesCacheStagePurgeRequestArgs', 'EdgeServicesCacheStagePurgeRequestArgsDict']]]]] = None,
                 refresh_cache: Optional[pulumi.Input[_builtins.str]] = None,
                 route_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 waf_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Edge Services Cache Stages.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.edgeservices.CacheStage("main",
            pipeline_id=main_scaleway_edge_services_pipeline["id"],
            backend_stage_id=main_scaleway_edge_services_backend_stage["id"])
        ```

        ### Purge request

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.edgeservices.CacheStage("main",
            pipeline_id=main_scaleway_edge_services_pipeline["id"],
            backend_stage_id=main_scaleway_edge_services_backend_stage["id"],
            purge=[{
                "pipelineId": main_scaleway_edge_services_pipeline["id"],
                "all": True,
            }])
        ```

        ## Import

        Cache stages can be imported using the `{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/edgeServicesCacheStage:EdgeServicesCacheStage basic 11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] backend_stage_id: The backend stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        :param pulumi.Input[_builtins.int] fallback_ttl: The Time To Live (TTL) in seconds. Defines how long content is cached.
        :param pulumi.Input[_builtins.bool] include_cookies: Defines whether responses to requests with cookies must be stored in the cache.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cache stage is associated with.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EdgeServicesCacheStagePurgeRequestArgs', 'EdgeServicesCacheStagePurgeRequestArgsDict']]]] purge_requests: The Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        :param pulumi.Input[_builtins.str] refresh_cache: Trigger a refresh of the cache by changing this field's value.
        :param pulumi.Input[_builtins.str] route_stage_id: The route stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        :param pulumi.Input[_builtins.str] waf_stage_id: The WAF stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EdgeServicesCacheStageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Edge Services Cache Stages.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.edgeservices.CacheStage("main",
            pipeline_id=main_scaleway_edge_services_pipeline["id"],
            backend_stage_id=main_scaleway_edge_services_backend_stage["id"])
        ```

        ### Purge request

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.edgeservices.CacheStage("main",
            pipeline_id=main_scaleway_edge_services_pipeline["id"],
            backend_stage_id=main_scaleway_edge_services_backend_stage["id"],
            purge=[{
                "pipelineId": main_scaleway_edge_services_pipeline["id"],
                "all": True,
            }])
        ```

        ## Import

        Cache stages can be imported using the `{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/edgeServicesCacheStage:EdgeServicesCacheStage basic 11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param EdgeServicesCacheStageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EdgeServicesCacheStageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 fallback_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 include_cookies: Optional[pulumi.Input[_builtins.bool]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 purge_requests: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EdgeServicesCacheStagePurgeRequestArgs', 'EdgeServicesCacheStagePurgeRequestArgsDict']]]]] = None,
                 refresh_cache: Optional[pulumi.Input[_builtins.str]] = None,
                 route_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 waf_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""EdgeServicesCacheStage is deprecated: scaleway.index/edgeservicescachestage.EdgeServicesCacheStage has been deprecated in favor of scaleway.edgeservices/cachestage.CacheStage""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EdgeServicesCacheStageArgs.__new__(EdgeServicesCacheStageArgs)

            __props__.__dict__["backend_stage_id"] = backend_stage_id
            __props__.__dict__["fallback_ttl"] = fallback_ttl
            __props__.__dict__["include_cookies"] = include_cookies
            if pipeline_id is None and not opts.urn:
                raise TypeError("Missing required property 'pipeline_id'")
            __props__.__dict__["pipeline_id"] = pipeline_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["purge_requests"] = purge_requests
            __props__.__dict__["refresh_cache"] = refresh_cache
            __props__.__dict__["route_stage_id"] = route_stage_id
            __props__.__dict__["waf_stage_id"] = waf_stage_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["updated_at"] = None
        super(EdgeServicesCacheStage, __self__).__init__(
            'scaleway:index/edgeServicesCacheStage:EdgeServicesCacheStage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backend_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            fallback_ttl: Optional[pulumi.Input[_builtins.int]] = None,
            include_cookies: Optional[pulumi.Input[_builtins.bool]] = None,
            pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            purge_requests: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EdgeServicesCacheStagePurgeRequestArgs', 'EdgeServicesCacheStagePurgeRequestArgsDict']]]]] = None,
            refresh_cache: Optional[pulumi.Input[_builtins.str]] = None,
            route_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            waf_stage_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'EdgeServicesCacheStage':
        """
        Get an existing EdgeServicesCacheStage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] backend_stage_id: The backend stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the cache stage.
        :param pulumi.Input[_builtins.int] fallback_ttl: The Time To Live (TTL) in seconds. Defines how long content is cached.
        :param pulumi.Input[_builtins.bool] include_cookies: Defines whether responses to requests with cookies must be stored in the cache.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cache stage is associated with.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EdgeServicesCacheStagePurgeRequestArgs', 'EdgeServicesCacheStagePurgeRequestArgsDict']]]] purge_requests: The Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        :param pulumi.Input[_builtins.str] refresh_cache: Trigger a refresh of the cache by changing this field's value.
        :param pulumi.Input[_builtins.str] route_stage_id: The route stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the cache stage.
        :param pulumi.Input[_builtins.str] waf_stage_id: The WAF stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EdgeServicesCacheStageState.__new__(_EdgeServicesCacheStageState)

        __props__.__dict__["backend_stage_id"] = backend_stage_id
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["fallback_ttl"] = fallback_ttl
        __props__.__dict__["include_cookies"] = include_cookies
        __props__.__dict__["pipeline_id"] = pipeline_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["purge_requests"] = purge_requests
        __props__.__dict__["refresh_cache"] = refresh_cache
        __props__.__dict__["route_stage_id"] = route_stage_id
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["waf_stage_id"] = waf_stage_id
        return EdgeServicesCacheStage(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="backendStageId")
    def backend_stage_id(self) -> pulumi.Output[_builtins.str]:
        """
        The backend stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        """
        return pulumi.get(self, "backend_stage_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the creation of the cache stage.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="fallbackTtl")
    def fallback_ttl(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The Time To Live (TTL) in seconds. Defines how long content is cached.
        """
        return pulumi.get(self, "fallback_ttl")

    @_builtins.property
    @pulumi.getter(name="includeCookies")
    def include_cookies(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Defines whether responses to requests with cookies must be stored in the cache.
        """
        return pulumi.get(self, "include_cookies")

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the cache stage is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="purgeRequests")
    def purge_requests(self) -> pulumi.Output[Optional[Sequence['outputs.EdgeServicesCacheStagePurgeRequest']]]:
        """
        The Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        """
        return pulumi.get(self, "purge_requests")

    @_builtins.property
    @pulumi.getter(name="refreshCache")
    def refresh_cache(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Trigger a refresh of the cache by changing this field's value.
        """
        return pulumi.get(self, "refresh_cache")

    @_builtins.property
    @pulumi.getter(name="routeStageId")
    def route_stage_id(self) -> pulumi.Output[_builtins.str]:
        """
        The route stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        """
        return pulumi.get(self, "route_stage_id")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the last update of the cache stage.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="wafStageId")
    def waf_stage_id(self) -> pulumi.Output[_builtins.str]:
        """
        The WAF stage ID the cache stage will be linked to. Only one of `backend_stage_id`, `route_stage_id` and `waf_stage_id` should be specified.
        """
        return pulumi.get(self, "waf_stage_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetConnectionResult',
    'AwaitableGetConnectionResult',
    'get_connection',
    'get_connection_output',
]

@pulumi.output_type
class GetConnectionResult:
    """
    A collection of values returned by getConnection.
    """
    def __init__(__self__, bgp_config_ipv4s=None, bgp_config_ipv6s=None, bgp_session_ipv4s=None, bgp_session_ipv6s=None, bgp_status_ipv4=None, bgp_status_ipv6=None, connection_id=None, created_at=None, customer_gateway_id=None, enable_route_propagation=None, esp_ciphers=None, id=None, ikev2_ciphers=None, initiation_policy=None, is_ipv6=None, name=None, organization_id=None, project_id=None, region=None, route_propagation_enabled=None, secret_id=None, secret_version=None, status=None, tags=None, tunnel_status=None, updated_at=None, vpn_gateway_id=None):
        if bgp_config_ipv4s and not isinstance(bgp_config_ipv4s, list):
            raise TypeError("Expected argument 'bgp_config_ipv4s' to be a list")
        pulumi.set(__self__, "bgp_config_ipv4s", bgp_config_ipv4s)
        if bgp_config_ipv6s and not isinstance(bgp_config_ipv6s, list):
            raise TypeError("Expected argument 'bgp_config_ipv6s' to be a list")
        pulumi.set(__self__, "bgp_config_ipv6s", bgp_config_ipv6s)
        if bgp_session_ipv4s and not isinstance(bgp_session_ipv4s, list):
            raise TypeError("Expected argument 'bgp_session_ipv4s' to be a list")
        pulumi.set(__self__, "bgp_session_ipv4s", bgp_session_ipv4s)
        if bgp_session_ipv6s and not isinstance(bgp_session_ipv6s, list):
            raise TypeError("Expected argument 'bgp_session_ipv6s' to be a list")
        pulumi.set(__self__, "bgp_session_ipv6s", bgp_session_ipv6s)
        if bgp_status_ipv4 and not isinstance(bgp_status_ipv4, str):
            raise TypeError("Expected argument 'bgp_status_ipv4' to be a str")
        pulumi.set(__self__, "bgp_status_ipv4", bgp_status_ipv4)
        if bgp_status_ipv6 and not isinstance(bgp_status_ipv6, str):
            raise TypeError("Expected argument 'bgp_status_ipv6' to be a str")
        pulumi.set(__self__, "bgp_status_ipv6", bgp_status_ipv6)
        if connection_id and not isinstance(connection_id, str):
            raise TypeError("Expected argument 'connection_id' to be a str")
        pulumi.set(__self__, "connection_id", connection_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if customer_gateway_id and not isinstance(customer_gateway_id, str):
            raise TypeError("Expected argument 'customer_gateway_id' to be a str")
        pulumi.set(__self__, "customer_gateway_id", customer_gateway_id)
        if enable_route_propagation and not isinstance(enable_route_propagation, bool):
            raise TypeError("Expected argument 'enable_route_propagation' to be a bool")
        pulumi.set(__self__, "enable_route_propagation", enable_route_propagation)
        if esp_ciphers and not isinstance(esp_ciphers, list):
            raise TypeError("Expected argument 'esp_ciphers' to be a list")
        pulumi.set(__self__, "esp_ciphers", esp_ciphers)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ikev2_ciphers and not isinstance(ikev2_ciphers, list):
            raise TypeError("Expected argument 'ikev2_ciphers' to be a list")
        pulumi.set(__self__, "ikev2_ciphers", ikev2_ciphers)
        if initiation_policy and not isinstance(initiation_policy, str):
            raise TypeError("Expected argument 'initiation_policy' to be a str")
        pulumi.set(__self__, "initiation_policy", initiation_policy)
        if is_ipv6 and not isinstance(is_ipv6, bool):
            raise TypeError("Expected argument 'is_ipv6' to be a bool")
        pulumi.set(__self__, "is_ipv6", is_ipv6)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if route_propagation_enabled and not isinstance(route_propagation_enabled, bool):
            raise TypeError("Expected argument 'route_propagation_enabled' to be a bool")
        pulumi.set(__self__, "route_propagation_enabled", route_propagation_enabled)
        if secret_id and not isinstance(secret_id, str):
            raise TypeError("Expected argument 'secret_id' to be a str")
        pulumi.set(__self__, "secret_id", secret_id)
        if secret_version and not isinstance(secret_version, int):
            raise TypeError("Expected argument 'secret_version' to be a int")
        pulumi.set(__self__, "secret_version", secret_version)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if tunnel_status and not isinstance(tunnel_status, str):
            raise TypeError("Expected argument 'tunnel_status' to be a str")
        pulumi.set(__self__, "tunnel_status", tunnel_status)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if vpn_gateway_id and not isinstance(vpn_gateway_id, str):
            raise TypeError("Expected argument 'vpn_gateway_id' to be a str")
        pulumi.set(__self__, "vpn_gateway_id", vpn_gateway_id)

    @_builtins.property
    @pulumi.getter(name="bgpConfigIpv4s")
    def bgp_config_ipv4s(self) -> Sequence['outputs.GetConnectionBgpConfigIpv4Result']:
        """
        The BGP IPv4 configuration.
        """
        return pulumi.get(self, "bgp_config_ipv4s")

    @_builtins.property
    @pulumi.getter(name="bgpConfigIpv6s")
    def bgp_config_ipv6s(self) -> Sequence['outputs.GetConnectionBgpConfigIpv6Result']:
        """
        The BGP IPv6 configuration.
        """
        return pulumi.get(self, "bgp_config_ipv6s")

    @_builtins.property
    @pulumi.getter(name="bgpSessionIpv4s")
    def bgp_session_ipv4s(self) -> Sequence['outputs.GetConnectionBgpSessionIpv4Result']:
        """
        The BGP IPv4 session information.
        """
        return pulumi.get(self, "bgp_session_ipv4s")

    @_builtins.property
    @pulumi.getter(name="bgpSessionIpv6s")
    def bgp_session_ipv6s(self) -> Sequence['outputs.GetConnectionBgpSessionIpv6Result']:
        """
        The BGP IPv6 session information.
        """
        return pulumi.get(self, "bgp_session_ipv6s")

    @_builtins.property
    @pulumi.getter(name="bgpStatusIpv4")
    def bgp_status_ipv4(self) -> _builtins.str:
        """
        The status of the BGP IPv4 session.
        """
        return pulumi.get(self, "bgp_status_ipv4")

    @_builtins.property
    @pulumi.getter(name="bgpStatusIpv6")
    def bgp_status_ipv6(self) -> _builtins.str:
        """
        The status of the BGP IPv6 session.
        """
        return pulumi.get(self, "bgp_status_ipv6")

    @_builtins.property
    @pulumi.getter(name="connectionId")
    def connection_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "connection_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        The date and time of creation of the connection.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="customerGatewayId")
    def customer_gateway_id(self) -> _builtins.str:
        """
        The ID of the customer gateway attached to the connection.
        """
        return pulumi.get(self, "customer_gateway_id")

    @_builtins.property
    @pulumi.getter(name="enableRoutePropagation")
    def enable_route_propagation(self) -> _builtins.bool:
        """
        Whether route propagation is enabled.
        """
        return pulumi.get(self, "enable_route_propagation")

    @_builtins.property
    @pulumi.getter(name="espCiphers")
    def esp_ciphers(self) -> Sequence['outputs.GetConnectionEspCipherResult']:
        """
        The ESP ciphers configuration.
        """
        return pulumi.get(self, "esp_ciphers")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="ikev2Ciphers")
    def ikev2_ciphers(self) -> Sequence['outputs.GetConnectionIkev2CipherResult']:
        """
        The IKEv2 ciphers configuration.
        """
        return pulumi.get(self, "ikev2_ciphers")

    @_builtins.property
    @pulumi.getter(name="initiationPolicy")
    def initiation_policy(self) -> _builtins.str:
        """
        Who initiates the IPSec tunnel.
        """
        return pulumi.get(self, "initiation_policy")

    @_builtins.property
    @pulumi.getter(name="isIpv6")
    def is_ipv6(self) -> _builtins.bool:
        """
        Whether the IPSec tunnel uses IPv6.
        """
        return pulumi.get(self, "is_ipv6")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        """
        The Organization ID the connection is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="routePropagationEnabled")
    def route_propagation_enabled(self) -> _builtins.bool:
        """
        Whether route propagation is currently enabled.
        """
        return pulumi.get(self, "route_propagation_enabled")

    @_builtins.property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> _builtins.str:
        """
        The ID of the secret containing the pre-shared key (PSK).
        """
        return pulumi.get(self, "secret_id")

    @_builtins.property
    @pulumi.getter(name="secretVersion")
    def secret_version(self) -> _builtins.int:
        """
        The version of the secret containing the PSK.
        """
        return pulumi.get(self, "secret_version")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status of the connection.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        The tags associated with the connection.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="tunnelStatus")
    def tunnel_status(self) -> _builtins.str:
        """
        The status of the IPSec tunnel.
        """
        return pulumi.get(self, "tunnel_status")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        The date and time of the last update of the connection.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> _builtins.str:
        """
        The ID of the VPN gateway attached to the connection.
        """
        return pulumi.get(self, "vpn_gateway_id")


class AwaitableGetConnectionResult(GetConnectionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetConnectionResult(
            bgp_config_ipv4s=self.bgp_config_ipv4s,
            bgp_config_ipv6s=self.bgp_config_ipv6s,
            bgp_session_ipv4s=self.bgp_session_ipv4s,
            bgp_session_ipv6s=self.bgp_session_ipv6s,
            bgp_status_ipv4=self.bgp_status_ipv4,
            bgp_status_ipv6=self.bgp_status_ipv6,
            connection_id=self.connection_id,
            created_at=self.created_at,
            customer_gateway_id=self.customer_gateway_id,
            enable_route_propagation=self.enable_route_propagation,
            esp_ciphers=self.esp_ciphers,
            id=self.id,
            ikev2_ciphers=self.ikev2_ciphers,
            initiation_policy=self.initiation_policy,
            is_ipv6=self.is_ipv6,
            name=self.name,
            organization_id=self.organization_id,
            project_id=self.project_id,
            region=self.region,
            route_propagation_enabled=self.route_propagation_enabled,
            secret_id=self.secret_id,
            secret_version=self.secret_version,
            status=self.status,
            tags=self.tags,
            tunnel_status=self.tunnel_status,
            updated_at=self.updated_at,
            vpn_gateway_id=self.vpn_gateway_id)


def get_connection(connection_id: Optional[_builtins.str] = None,
                   name: Optional[_builtins.str] = None,
                   project_id: Optional[_builtins.str] = None,
                   region: Optional[_builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetConnectionResult:
    """
    For further information refer to the Site-to-Site VPN [API documentation](https://www.scaleway.com/en/developers/api/site-to-site-vpn/).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by connection ID
    my_connection = scaleway.s2svpn.get_connection(connection_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by name
    my_connection = scaleway.s2svpn.get_connection(name="foobar")
    ```


    :param _builtins.str connection_id: The connection ID.
           
           > **Note** You must specify at least one: `name` and/or `connection_id`.
    :param _builtins.str name: The name of the connection.
    :param _builtins.str project_id: The ID of the project the connection is associated with.
    :param _builtins.str region: `region`) The region in which the connection exists.
    """
    __args__ = dict()
    __args__['connectionId'] = connection_id
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:s2svpn/getConnection:getConnection', __args__, opts=opts, typ=GetConnectionResult).value

    return AwaitableGetConnectionResult(
        bgp_config_ipv4s=pulumi.get(__ret__, 'bgp_config_ipv4s'),
        bgp_config_ipv6s=pulumi.get(__ret__, 'bgp_config_ipv6s'),
        bgp_session_ipv4s=pulumi.get(__ret__, 'bgp_session_ipv4s'),
        bgp_session_ipv6s=pulumi.get(__ret__, 'bgp_session_ipv6s'),
        bgp_status_ipv4=pulumi.get(__ret__, 'bgp_status_ipv4'),
        bgp_status_ipv6=pulumi.get(__ret__, 'bgp_status_ipv6'),
        connection_id=pulumi.get(__ret__, 'connection_id'),
        created_at=pulumi.get(__ret__, 'created_at'),
        customer_gateway_id=pulumi.get(__ret__, 'customer_gateway_id'),
        enable_route_propagation=pulumi.get(__ret__, 'enable_route_propagation'),
        esp_ciphers=pulumi.get(__ret__, 'esp_ciphers'),
        id=pulumi.get(__ret__, 'id'),
        ikev2_ciphers=pulumi.get(__ret__, 'ikev2_ciphers'),
        initiation_policy=pulumi.get(__ret__, 'initiation_policy'),
        is_ipv6=pulumi.get(__ret__, 'is_ipv6'),
        name=pulumi.get(__ret__, 'name'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'),
        route_propagation_enabled=pulumi.get(__ret__, 'route_propagation_enabled'),
        secret_id=pulumi.get(__ret__, 'secret_id'),
        secret_version=pulumi.get(__ret__, 'secret_version'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        tunnel_status=pulumi.get(__ret__, 'tunnel_status'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        vpn_gateway_id=pulumi.get(__ret__, 'vpn_gateway_id'))
def get_connection_output(connection_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetConnectionResult]:
    """
    For further information refer to the Site-to-Site VPN [API documentation](https://www.scaleway.com/en/developers/api/site-to-site-vpn/).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by connection ID
    my_connection = scaleway.s2svpn.get_connection(connection_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by name
    my_connection = scaleway.s2svpn.get_connection(name="foobar")
    ```


    :param _builtins.str connection_id: The connection ID.
           
           > **Note** You must specify at least one: `name` and/or `connection_id`.
    :param _builtins.str name: The name of the connection.
    :param _builtins.str project_id: The ID of the project the connection is associated with.
    :param _builtins.str region: `region`) The region in which the connection exists.
    """
    __args__ = dict()
    __args__['connectionId'] = connection_id
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:s2svpn/getConnection:getConnection', __args__, opts=opts, typ=GetConnectionResult)
    return __ret__.apply(lambda __response__: GetConnectionResult(
        bgp_config_ipv4s=pulumi.get(__response__, 'bgp_config_ipv4s'),
        bgp_config_ipv6s=pulumi.get(__response__, 'bgp_config_ipv6s'),
        bgp_session_ipv4s=pulumi.get(__response__, 'bgp_session_ipv4s'),
        bgp_session_ipv6s=pulumi.get(__response__, 'bgp_session_ipv6s'),
        bgp_status_ipv4=pulumi.get(__response__, 'bgp_status_ipv4'),
        bgp_status_ipv6=pulumi.get(__response__, 'bgp_status_ipv6'),
        connection_id=pulumi.get(__response__, 'connection_id'),
        created_at=pulumi.get(__response__, 'created_at'),
        customer_gateway_id=pulumi.get(__response__, 'customer_gateway_id'),
        enable_route_propagation=pulumi.get(__response__, 'enable_route_propagation'),
        esp_ciphers=pulumi.get(__response__, 'esp_ciphers'),
        id=pulumi.get(__response__, 'id'),
        ikev2_ciphers=pulumi.get(__response__, 'ikev2_ciphers'),
        initiation_policy=pulumi.get(__response__, 'initiation_policy'),
        is_ipv6=pulumi.get(__response__, 'is_ipv6'),
        name=pulumi.get(__response__, 'name'),
        organization_id=pulumi.get(__response__, 'organization_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region'),
        route_propagation_enabled=pulumi.get(__response__, 'route_propagation_enabled'),
        secret_id=pulumi.get(__response__, 'secret_id'),
        secret_version=pulumi.get(__response__, 'secret_version'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        tunnel_status=pulumi.get(__response__, 'tunnel_status'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        vpn_gateway_id=pulumi.get(__response__, 'vpn_gateway_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'DeviceCertificateArgs',
    'DeviceCertificateArgsDict',
    'DeviceMessageFiltersArgs',
    'DeviceMessageFiltersArgsDict',
    'DeviceMessageFiltersPublishArgs',
    'DeviceMessageFiltersPublishArgsDict',
    'DeviceMessageFiltersSubscribeArgs',
    'DeviceMessageFiltersSubscribeArgsDict',
    'RouteDatabaseArgs',
    'RouteDatabaseArgsDict',
    'RouteRestArgs',
    'RouteRestArgsDict',
    'RouteS3Args',
    'RouteS3ArgsDict',
]

MYPY = False

if not MYPY:
    class DeviceCertificateArgsDict(TypedDict):
        crt: NotRequired[pulumi.Input[_builtins.str]]
        """
        X509 PEM encoded certificate of the device
        """
        key: NotRequired[pulumi.Input[_builtins.str]]
        """
        The private key of the device, in case it is generated by Scaleway.
        """
elif False:
    DeviceCertificateArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DeviceCertificateArgs:
    def __init__(__self__, *,
                 crt: Optional[pulumi.Input[_builtins.str]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] crt: X509 PEM encoded certificate of the device
        :param pulumi.Input[_builtins.str] key: The private key of the device, in case it is generated by Scaleway.
        """
        if crt is not None:
            pulumi.set(__self__, "crt", crt)
        if key is not None:
            pulumi.set(__self__, "key", key)

    @_builtins.property
    @pulumi.getter
    def crt(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        X509 PEM encoded certificate of the device
        """
        return pulumi.get(self, "crt")

    @crt.setter
    def crt(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "crt", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The private key of the device, in case it is generated by Scaleway.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "key", value)


if not MYPY:
    class DeviceMessageFiltersArgsDict(TypedDict):
        publish: NotRequired[pulumi.Input['DeviceMessageFiltersPublishArgsDict']]
        """
        Rules used to restrict topics the device can publish to.
        """
        subscribe: NotRequired[pulumi.Input['DeviceMessageFiltersSubscribeArgsDict']]
        """
        Rules used to restrict topics the device can subscribe to.
        """
elif False:
    DeviceMessageFiltersArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DeviceMessageFiltersArgs:
    def __init__(__self__, *,
                 publish: Optional[pulumi.Input['DeviceMessageFiltersPublishArgs']] = None,
                 subscribe: Optional[pulumi.Input['DeviceMessageFiltersSubscribeArgs']] = None):
        """
        :param pulumi.Input['DeviceMessageFiltersPublishArgs'] publish: Rules used to restrict topics the device can publish to.
        :param pulumi.Input['DeviceMessageFiltersSubscribeArgs'] subscribe: Rules used to restrict topics the device can subscribe to.
        """
        if publish is not None:
            pulumi.set(__self__, "publish", publish)
        if subscribe is not None:
            pulumi.set(__self__, "subscribe", subscribe)

    @_builtins.property
    @pulumi.getter
    def publish(self) -> Optional[pulumi.Input['DeviceMessageFiltersPublishArgs']]:
        """
        Rules used to restrict topics the device can publish to.
        """
        return pulumi.get(self, "publish")

    @publish.setter
    def publish(self, value: Optional[pulumi.Input['DeviceMessageFiltersPublishArgs']]):
        pulumi.set(self, "publish", value)

    @_builtins.property
    @pulumi.getter
    def subscribe(self) -> Optional[pulumi.Input['DeviceMessageFiltersSubscribeArgs']]:
        """
        Rules used to restrict topics the device can subscribe to.
        """
        return pulumi.get(self, "subscribe")

    @subscribe.setter
    def subscribe(self, value: Optional[pulumi.Input['DeviceMessageFiltersSubscribeArgs']]):
        pulumi.set(self, "subscribe", value)


if not MYPY:
    class DeviceMessageFiltersPublishArgsDict(TypedDict):
        policy: NotRequired[pulumi.Input[_builtins.str]]
        """
        Filtering policy (eg `accept` or `reject`)
        """
        topics: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        """
        List of topics to match (eg `foo/bar/+/baz/#`)
        """
elif False:
    DeviceMessageFiltersPublishArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DeviceMessageFiltersPublishArgs:
    def __init__(__self__, *,
                 policy: Optional[pulumi.Input[_builtins.str]] = None,
                 topics: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        :param pulumi.Input[_builtins.str] policy: Filtering policy (eg `accept` or `reject`)
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] topics: List of topics to match (eg `foo/bar/+/baz/#`)
        """
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if topics is not None:
            pulumi.set(__self__, "topics", topics)

    @_builtins.property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Filtering policy (eg `accept` or `reject`)
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy", value)

    @_builtins.property
    @pulumi.getter
    def topics(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of topics to match (eg `foo/bar/+/baz/#`)
        """
        return pulumi.get(self, "topics")

    @topics.setter
    def topics(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "topics", value)


if not MYPY:
    class DeviceMessageFiltersSubscribeArgsDict(TypedDict):
        policy: NotRequired[pulumi.Input[_builtins.str]]
        """
        Same as publish rules.
        """
        topics: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        """
        Same as publish rules.

        - `certificate.crt` - (Optional) The certificate of the device, either generated by Scaleway or provided.

        > **Important:** Updates to `certificate.crt` will disconnect connected devices and the previous certificate will be deleted and won't be recoverable.
        """
elif False:
    DeviceMessageFiltersSubscribeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DeviceMessageFiltersSubscribeArgs:
    def __init__(__self__, *,
                 policy: Optional[pulumi.Input[_builtins.str]] = None,
                 topics: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        :param pulumi.Input[_builtins.str] policy: Same as publish rules.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] topics: Same as publish rules.
               
               - `certificate.crt` - (Optional) The certificate of the device, either generated by Scaleway or provided.
               
               > **Important:** Updates to `certificate.crt` will disconnect connected devices and the previous certificate will be deleted and won't be recoverable.
        """
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if topics is not None:
            pulumi.set(__self__, "topics", topics)

    @_builtins.property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Same as publish rules.
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy", value)

    @_builtins.property
    @pulumi.getter
    def topics(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Same as publish rules.

        - `certificate.crt` - (Optional) The certificate of the device, either generated by Scaleway or provided.

        > **Important:** Updates to `certificate.crt` will disconnect connected devices and the previous certificate will be deleted and won't be recoverable.
        """
        return pulumi.get(self, "topics")

    @topics.setter
    def topics(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "topics", value)


if not MYPY:
    class RouteDatabaseArgsDict(TypedDict):
        dbname: pulumi.Input[_builtins.str]
        """
        The database name (e.g. `measurements`).
        """
        host: pulumi.Input[_builtins.str]
        """
        The database hostname. Can be an IP or a FQDN.
        """
        password: pulumi.Input[_builtins.str]
        """
        The database password.
        """
        port: pulumi.Input[_builtins.int]
        """
        The database port (e.g. `5432`)
        """
        query: pulumi.Input[_builtins.str]
        """
        The SQL query that will be executed when receiving a message ($TOPIC and $PAYLOAD variables are available, see documentation, e.g. `INSERT INTO mytable(date, topic, value) VALUES (NOW(), $TOPIC, $PAYLOAD)`).
        """
        username: pulumi.Input[_builtins.str]
        """
        The database username.
        """
elif False:
    RouteDatabaseArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RouteDatabaseArgs:
    def __init__(__self__, *,
                 dbname: pulumi.Input[_builtins.str],
                 host: pulumi.Input[_builtins.str],
                 password: pulumi.Input[_builtins.str],
                 port: pulumi.Input[_builtins.int],
                 query: pulumi.Input[_builtins.str],
                 username: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.str] dbname: The database name (e.g. `measurements`).
        :param pulumi.Input[_builtins.str] host: The database hostname. Can be an IP or a FQDN.
        :param pulumi.Input[_builtins.str] password: The database password.
        :param pulumi.Input[_builtins.int] port: The database port (e.g. `5432`)
        :param pulumi.Input[_builtins.str] query: The SQL query that will be executed when receiving a message ($TOPIC and $PAYLOAD variables are available, see documentation, e.g. `INSERT INTO mytable(date, topic, value) VALUES (NOW(), $TOPIC, $PAYLOAD)`).
        :param pulumi.Input[_builtins.str] username: The database username.
        """
        pulumi.set(__self__, "dbname", dbname)
        pulumi.set(__self__, "host", host)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "query", query)
        pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter
    def dbname(self) -> pulumi.Input[_builtins.str]:
        """
        The database name (e.g. `measurements`).
        """
        return pulumi.get(self, "dbname")

    @dbname.setter
    def dbname(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "dbname", value)

    @_builtins.property
    @pulumi.getter
    def host(self) -> pulumi.Input[_builtins.str]:
        """
        The database hostname. Can be an IP or a FQDN.
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "host", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Input[_builtins.str]:
        """
        The database password.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> pulumi.Input[_builtins.int]:
        """
        The database port (e.g. `5432`)
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter
    def query(self) -> pulumi.Input[_builtins.str]:
        """
        The SQL query that will be executed when receiving a message ($TOPIC and $PAYLOAD variables are available, see documentation, e.g. `INSERT INTO mytable(date, topic, value) VALUES (NOW(), $TOPIC, $PAYLOAD)`).
        """
        return pulumi.get(self, "query")

    @query.setter
    def query(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "query", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> pulumi.Input[_builtins.str]:
        """
        The database username.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "username", value)


if not MYPY:
    class RouteRestArgsDict(TypedDict):
        headers: pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]
        """
        a map of the extra headers to send with the HTTP call (e.g. `X-Header = Value`).
        """
        uri: pulumi.Input[_builtins.str]
        """
        The URI of the Rest endpoint (e.g. `https://internal.mycompany.com/ingest/mqttdata`).
        """
        verb: pulumi.Input[_builtins.str]
        """
        The HTTP Verb used to call Rest URI (e.g. `post`).
        """
elif False:
    RouteRestArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RouteRestArgs:
    def __init__(__self__, *,
                 headers: pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]],
                 uri: pulumi.Input[_builtins.str],
                 verb: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] headers: a map of the extra headers to send with the HTTP call (e.g. `X-Header = Value`).
        :param pulumi.Input[_builtins.str] uri: The URI of the Rest endpoint (e.g. `https://internal.mycompany.com/ingest/mqttdata`).
        :param pulumi.Input[_builtins.str] verb: The HTTP Verb used to call Rest URI (e.g. `post`).
        """
        pulumi.set(__self__, "headers", headers)
        pulumi.set(__self__, "uri", uri)
        pulumi.set(__self__, "verb", verb)

    @_builtins.property
    @pulumi.getter
    def headers(self) -> pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]:
        """
        a map of the extra headers to send with the HTTP call (e.g. `X-Header = Value`).
        """
        return pulumi.get(self, "headers")

    @headers.setter
    def headers(self, value: pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "headers", value)

    @_builtins.property
    @pulumi.getter
    def uri(self) -> pulumi.Input[_builtins.str]:
        """
        The URI of the Rest endpoint (e.g. `https://internal.mycompany.com/ingest/mqttdata`).
        """
        return pulumi.get(self, "uri")

    @uri.setter
    def uri(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "uri", value)

    @_builtins.property
    @pulumi.getter
    def verb(self) -> pulumi.Input[_builtins.str]:
        """
        The HTTP Verb used to call Rest URI (e.g. `post`).
        """
        return pulumi.get(self, "verb")

    @verb.setter
    def verb(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "verb", value)


if not MYPY:
    class RouteS3ArgsDict(TypedDict):
        bucket_name: pulumi.Input[_builtins.str]
        """
        The name of the S3 route's destination bucket (e.g. `my-object-storage`).
        """
        bucket_region: pulumi.Input[_builtins.str]
        """
        The region of the S3 route's destination bucket (e.g. `fr-par`).
        """
        strategy: pulumi.Input[_builtins.str]
        """
        How the S3 route's objects will be created (e.g. `per_topic`). See [documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for behaviour details.
        """
        object_prefix: NotRequired[pulumi.Input[_builtins.str]]
        """
        The string to prefix object names with (e.g. `mykeyprefix-`).
        """
elif False:
    RouteS3ArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RouteS3Args:
    def __init__(__self__, *,
                 bucket_name: pulumi.Input[_builtins.str],
                 bucket_region: pulumi.Input[_builtins.str],
                 strategy: pulumi.Input[_builtins.str],
                 object_prefix: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] bucket_name: The name of the S3 route's destination bucket (e.g. `my-object-storage`).
        :param pulumi.Input[_builtins.str] bucket_region: The region of the S3 route's destination bucket (e.g. `fr-par`).
        :param pulumi.Input[_builtins.str] strategy: How the S3 route's objects will be created (e.g. `per_topic`). See [documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for behaviour details.
        :param pulumi.Input[_builtins.str] object_prefix: The string to prefix object names with (e.g. `mykeyprefix-`).
        """
        pulumi.set(__self__, "bucket_name", bucket_name)
        pulumi.set(__self__, "bucket_region", bucket_region)
        pulumi.set(__self__, "strategy", strategy)
        if object_prefix is not None:
            pulumi.set(__self__, "object_prefix", object_prefix)

    @_builtins.property
    @pulumi.getter(name="bucketName")
    def bucket_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the S3 route's destination bucket (e.g. `my-object-storage`).
        """
        return pulumi.get(self, "bucket_name")

    @bucket_name.setter
    def bucket_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "bucket_name", value)

    @_builtins.property
    @pulumi.getter(name="bucketRegion")
    def bucket_region(self) -> pulumi.Input[_builtins.str]:
        """
        The region of the S3 route's destination bucket (e.g. `fr-par`).
        """
        return pulumi.get(self, "bucket_region")

    @bucket_region.setter
    def bucket_region(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "bucket_region", value)

    @_builtins.property
    @pulumi.getter
    def strategy(self) -> pulumi.Input[_builtins.str]:
        """
        How the S3 route's objects will be created (e.g. `per_topic`). See [documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for behaviour details.
        """
        return pulumi.get(self, "strategy")

    @strategy.setter
    def strategy(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "strategy", value)

    @_builtins.property
    @pulumi.getter(name="objectPrefix")
    def object_prefix(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The string to prefix object names with (e.g. `mykeyprefix-`).
        """
        return pulumi.get(self, "object_prefix")

    @object_prefix.setter
    def object_prefix(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "object_prefix", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPreconfiguredAlertResult',
    'AwaitableGetPreconfiguredAlertResult',
    'get_preconfigured_alert',
    'get_preconfigured_alert_output',
]

@pulumi.output_type
class GetPreconfiguredAlertResult:
    """
    A collection of values returned by getPreconfiguredAlert.
    """
    def __init__(__self__, alerts=None, data_source_id=None, id=None, project_id=None, region=None, rule_status=None):
        if alerts and not isinstance(alerts, list):
            raise TypeError("Expected argument 'alerts' to be a list")
        pulumi.set(__self__, "alerts", alerts)
        if data_source_id and not isinstance(data_source_id, str):
            raise TypeError("Expected argument 'data_source_id' to be a str")
        pulumi.set(__self__, "data_source_id", data_source_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if rule_status and not isinstance(rule_status, str):
            raise TypeError("Expected argument 'rule_status' to be a str")
        pulumi.set(__self__, "rule_status", rule_status)

    @_builtins.property
    @pulumi.getter
    def alerts(self) -> Sequence['outputs.GetPreconfiguredAlertAlertResult']:
        """
        List of preconfigured alerts. Each alert contains:
        """
        return pulumi.get(self, "alerts")

    @_builtins.property
    @pulumi.getter(name="dataSourceId")
    def data_source_id(self) -> Optional[_builtins.str]:
        """
        ID of the data source containing the alert rule.
        """
        return pulumi.get(self, "data_source_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="ruleStatus")
    def rule_status(self) -> Optional[_builtins.str]:
        """
        Status of the alert rule (`enabled`, `disabled`, `enabling`, `disabling`).
        """
        return pulumi.get(self, "rule_status")


class AwaitableGetPreconfiguredAlertResult(GetPreconfiguredAlertResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPreconfiguredAlertResult(
            alerts=self.alerts,
            data_source_id=self.data_source_id,
            id=self.id,
            project_id=self.project_id,
            region=self.region,
            rule_status=self.rule_status)


def get_preconfigured_alert(data_source_id: Optional[_builtins.str] = None,
                            project_id: Optional[_builtins.str] = None,
                            region: Optional[_builtins.str] = None,
                            rule_status: Optional[_builtins.str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPreconfiguredAlertResult:
    """
    Gets information about preconfigured alert rules available in Scaleway Cockpit.

    Preconfigured alerts are ready-to-use alert rules that monitor common metrics for Scaleway services.
    You can enable these alerts in your Alert Manager using the `observability.AlertManager` resource.

    For more information, refer to Cockpit's [product documentation](https://www.scaleway.com/en/docs/observability/cockpit/concepts/) and [API documentation](https://www.scaleway.com/en/developers/api/cockpit/regional-api).

    ## Example Usage

    ### Basic usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    main = scaleway.observability.get_preconfigured_alert(project_id=project["id"])
    pulumi.export("availableAlerts", main.alerts)
    ```

    ### Filter by status

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    enabled = scaleway.observability.get_preconfigured_alert(project_id=project["id"],
        rule_status="enabled")
    disabled = scaleway.observability.get_preconfigured_alert(project_id=project["id"],
        rule_status="disabled")
    ```

    ### Use with Alert Manager

    ```python
    import pulumi
    import pulumi_scaleway as scaleway
    import pulumiverse_scaleway as scaleway

    project = scaleway.account.Project("project", name="my-observability-project")
    main = scaleway.observability.Cockpit("main", project_id=project.id)
    all = scaleway.observability.get_preconfigured_alert_output(project_id=main.project_id)
    main_alert_manager = scaleway.observability.AlertManager("main",
        project_id=main.project_id,
        preconfigured_alert_ids=all.apply(lambda all: [alert.preconfigured_rule_id for alert in all.alerts if alert.product_name == "instance" and alert.rule_status == "disabled"]),
        contact_points=[{
            "email": "alerts@example.com",
        }])
    ```


    :param _builtins.str data_source_id: Filter alerts by data source ID.
    :param _builtins.str project_id: The ID of the project the alerts are associated with. If not provided, the default project configured in the provider is used.
    :param _builtins.str region: The region in which the alerts exist.
    :param _builtins.str rule_status: Filter alerts by rule status. Valid values are `enabled` or `disabled`.
    """
    __args__ = dict()
    __args__['dataSourceId'] = data_source_id
    __args__['projectId'] = project_id
    __args__['region'] = region
    __args__['ruleStatus'] = rule_status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:observability/getPreconfiguredAlert:getPreconfiguredAlert', __args__, opts=opts, typ=GetPreconfiguredAlertResult).value

    return AwaitableGetPreconfiguredAlertResult(
        alerts=pulumi.get(__ret__, 'alerts'),
        data_source_id=pulumi.get(__ret__, 'data_source_id'),
        id=pulumi.get(__ret__, 'id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'),
        rule_status=pulumi.get(__ret__, 'rule_status'))
def get_preconfigured_alert_output(data_source_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   rule_status: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPreconfiguredAlertResult]:
    """
    Gets information about preconfigured alert rules available in Scaleway Cockpit.

    Preconfigured alerts are ready-to-use alert rules that monitor common metrics for Scaleway services.
    You can enable these alerts in your Alert Manager using the `observability.AlertManager` resource.

    For more information, refer to Cockpit's [product documentation](https://www.scaleway.com/en/docs/observability/cockpit/concepts/) and [API documentation](https://www.scaleway.com/en/developers/api/cockpit/regional-api).

    ## Example Usage

    ### Basic usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    main = scaleway.observability.get_preconfigured_alert(project_id=project["id"])
    pulumi.export("availableAlerts", main.alerts)
    ```

    ### Filter by status

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    enabled = scaleway.observability.get_preconfigured_alert(project_id=project["id"],
        rule_status="enabled")
    disabled = scaleway.observability.get_preconfigured_alert(project_id=project["id"],
        rule_status="disabled")
    ```

    ### Use with Alert Manager

    ```python
    import pulumi
    import pulumi_scaleway as scaleway
    import pulumiverse_scaleway as scaleway

    project = scaleway.account.Project("project", name="my-observability-project")
    main = scaleway.observability.Cockpit("main", project_id=project.id)
    all = scaleway.observability.get_preconfigured_alert_output(project_id=main.project_id)
    main_alert_manager = scaleway.observability.AlertManager("main",
        project_id=main.project_id,
        preconfigured_alert_ids=all.apply(lambda all: [alert.preconfigured_rule_id for alert in all.alerts if alert.product_name == "instance" and alert.rule_status == "disabled"]),
        contact_points=[{
            "email": "alerts@example.com",
        }])
    ```


    :param _builtins.str data_source_id: Filter alerts by data source ID.
    :param _builtins.str project_id: The ID of the project the alerts are associated with. If not provided, the default project configured in the provider is used.
    :param _builtins.str region: The region in which the alerts exist.
    :param _builtins.str rule_status: Filter alerts by rule status. Valid values are `enabled` or `disabled`.
    """
    __args__ = dict()
    __args__['dataSourceId'] = data_source_id
    __args__['projectId'] = project_id
    __args__['region'] = region
    __args__['ruleStatus'] = rule_status
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:observability/getPreconfiguredAlert:getPreconfiguredAlert', __args__, opts=opts, typ=GetPreconfiguredAlertResult)
    return __ret__.apply(lambda __response__: GetPreconfiguredAlertResult(
        alerts=pulumi.get(__response__, 'alerts'),
        data_source_id=pulumi.get(__response__, 'data_source_id'),
        id=pulumi.get(__response__, 'id'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region'),
        rule_status=pulumi.get(__response__, 'rule_status')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .acl import *
from .backend import *
from .certificate import *
from .frontend import *
from .get_acls import *
from .get_backend import *
from .get_backends import *
from .get_certificate import *
from .get_frontend import *
from .get_frontends import *
from .get_ip import *
from .get_ips import *
from .get_load_balancer import *
from .get_load_balancers import *
from .get_route import *
from .get_routes import *
from .ip import *
from .load_balancer import *
from .private_network import *
from .route import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AclAclRuleArgs',
    'AclAclRuleArgsDict',
    'InstanceLoadBalancerArgs',
    'InstanceLoadBalancerArgsDict',
    'InstanceLogsPolicyArgs',
    'InstanceLogsPolicyArgsDict',
    'InstancePrivateIpArgs',
    'InstancePrivateIpArgsDict',
    'InstancePrivateNetworkArgs',
    'InstancePrivateNetworkArgsDict',
    'InstanceReadReplicaArgs',
    'InstanceReadReplicaArgsDict',
    'InstanceUpgradableVersionArgs',
    'InstanceUpgradableVersionArgsDict',
    'ReadReplicaDirectAccessArgs',
    'ReadReplicaDirectAccessArgsDict',
    'ReadReplicaPrivateNetworkArgs',
    'ReadReplicaPrivateNetworkArgsDict',
]

MYPY = False

if not MYPY:
    class AclAclRuleArgsDict(TypedDict):
        ip: pulumi.Input[_builtins.str]
        """
        The IPv4 address or range to whitelist in [CIDR notation](https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation). IPv6 is not supported by the Scaleway API.
        """
        description: NotRequired[pulumi.Input[_builtins.str]]
        """
        A text describing this rule. Default description: `IP allowed`
        """
elif False:
    AclAclRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AclAclRuleArgs:
    def __init__(__self__, *,
                 ip: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] ip: The IPv4 address or range to whitelist in [CIDR notation](https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation). IPv6 is not supported by the Scaleway API.
        :param pulumi.Input[_builtins.str] description: A text describing this rule. Default description: `IP allowed`
        """
        pulumi.set(__self__, "ip", ip)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> pulumi.Input[_builtins.str]:
        """
        The IPv4 address or range to whitelist in [CIDR notation](https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation). IPv6 is not supported by the Scaleway API.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "ip", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A text describing this rule. Default description: `IP allowed`
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)


if not MYPY:
    class InstanceLoadBalancerArgsDict(TypedDict):
        endpoint_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the endpoint.
        """
        hostname: NotRequired[pulumi.Input[_builtins.str]]
        """
        Hostname of the endpoint.
        """
        ip: NotRequired[pulumi.Input[_builtins.str]]
        """
        IPv4 address on the network.
        """
        name: NotRequired[pulumi.Input[_builtins.str]]
        """
        The name of the Database Instance.
        """
        port: NotRequired[pulumi.Input[_builtins.int]]
        """
        Port in the Private Network.
        """
elif False:
    InstanceLoadBalancerArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceLoadBalancerArgs:
    def __init__(__self__, *,
                 endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 ip: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.str] endpoint_id: The ID of the endpoint.
        :param pulumi.Input[_builtins.str] hostname: Hostname of the endpoint.
        :param pulumi.Input[_builtins.str] ip: IPv4 address on the network.
        :param pulumi.Input[_builtins.str] name: The name of the Database Instance.
        :param pulumi.Input[_builtins.int] port: Port in the Private Network.
        """
        if endpoint_id is not None:
            pulumi.set(__self__, "endpoint_id", endpoint_id)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the endpoint.
        """
        return pulumi.get(self, "endpoint_id")

    @endpoint_id.setter
    def endpoint_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint_id", value)

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Hostname of the endpoint.
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hostname", value)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IPv4 address on the network.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Database Instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Port in the Private Network.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)


if not MYPY:
    class InstanceLogsPolicyArgsDict(TypedDict):
        max_age_retention: NotRequired[pulumi.Input[_builtins.int]]
        """
        The max age (in days) of remote logs to keep on the Database Instance
        """
        total_disk_retention: NotRequired[pulumi.Input[_builtins.int]]
        """
        The max disk size of remote logs to keep on the Database Instance.
        """
elif False:
    InstanceLogsPolicyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceLogsPolicyArgs:
    def __init__(__self__, *,
                 max_age_retention: Optional[pulumi.Input[_builtins.int]] = None,
                 total_disk_retention: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.int] max_age_retention: The max age (in days) of remote logs to keep on the Database Instance
        :param pulumi.Input[_builtins.int] total_disk_retention: The max disk size of remote logs to keep on the Database Instance.
        """
        if max_age_retention is not None:
            pulumi.set(__self__, "max_age_retention", max_age_retention)
        if total_disk_retention is not None:
            pulumi.set(__self__, "total_disk_retention", total_disk_retention)

    @_builtins.property
    @pulumi.getter(name="maxAgeRetention")
    def max_age_retention(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The max age (in days) of remote logs to keep on the Database Instance
        """
        return pulumi.get(self, "max_age_retention")

    @max_age_retention.setter
    def max_age_retention(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_age_retention", value)

    @_builtins.property
    @pulumi.getter(name="totalDiskRetention")
    def total_disk_retention(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The max disk size of remote logs to keep on the Database Instance.
        """
        return pulumi.get(self, "total_disk_retention")

    @total_disk_retention.setter
    def total_disk_retention(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "total_disk_retention", value)


if not MYPY:
    class InstancePrivateIpArgsDict(TypedDict):
        address: NotRequired[pulumi.Input[_builtins.str]]
        """
        The private IPv4 address.
        """
        id: NotRequired[pulumi.Input[_builtins.str]]
        """
        Version ID to use in upgrade requests.
        """
elif False:
    InstancePrivateIpArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstancePrivateIpArgs:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] address: The private IPv4 address.
        :param pulumi.Input[_builtins.str] id: Version ID to use in upgrade requests.
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if id is not None:
            pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The private IPv4 address.
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Version ID to use in upgrade requests.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)


if not MYPY:
    class InstancePrivateNetworkArgsDict(TypedDict):
        pn_id: pulumi.Input[_builtins.str]
        """
        The private network ID
        """
        enable_ipam: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Whether or not the private network endpoint should be configured with IPAM
        """
        endpoint_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the endpoint.
        """
        hostname: NotRequired[pulumi.Input[_builtins.str]]
        """
        Hostname of the endpoint.
        """
        ip: NotRequired[pulumi.Input[_builtins.str]]
        """
        IPv4 address on the network.
        """
        ip_net: NotRequired[pulumi.Input[_builtins.str]]
        """
        The IP with the given mask within the private subnet
        """
        name: NotRequired[pulumi.Input[_builtins.str]]
        """
        The name of the Database Instance.
        """
        port: NotRequired[pulumi.Input[_builtins.int]]
        """
        Port in the Private Network.
        """
        zone: NotRequired[pulumi.Input[_builtins.str]]
        """
        The zone you want to attach the resource to
        """
elif False:
    InstancePrivateNetworkArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstancePrivateNetworkArgs:
    def __init__(__self__, *,
                 pn_id: pulumi.Input[_builtins.str],
                 enable_ipam: Optional[pulumi.Input[_builtins.bool]] = None,
                 endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 ip: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_net: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] pn_id: The private network ID
        :param pulumi.Input[_builtins.bool] enable_ipam: Whether or not the private network endpoint should be configured with IPAM
        :param pulumi.Input[_builtins.str] endpoint_id: The ID of the endpoint.
        :param pulumi.Input[_builtins.str] hostname: Hostname of the endpoint.
        :param pulumi.Input[_builtins.str] ip: IPv4 address on the network.
        :param pulumi.Input[_builtins.str] ip_net: The IP with the given mask within the private subnet
        :param pulumi.Input[_builtins.str] name: The name of the Database Instance.
        :param pulumi.Input[_builtins.int] port: Port in the Private Network.
        :param pulumi.Input[_builtins.str] zone: The zone you want to attach the resource to
        """
        pulumi.set(__self__, "pn_id", pn_id)
        if enable_ipam is not None:
            pulumi.set(__self__, "enable_ipam", enable_ipam)
        if endpoint_id is not None:
            pulumi.set(__self__, "endpoint_id", endpoint_id)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if ip_net is not None:
            pulumi.set(__self__, "ip_net", ip_net)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="pnId")
    def pn_id(self) -> pulumi.Input[_builtins.str]:
        """
        The private network ID
        """
        return pulumi.get(self, "pn_id")

    @pn_id.setter
    def pn_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "pn_id", value)

    @_builtins.property
    @pulumi.getter(name="enableIpam")
    def enable_ipam(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether or not the private network endpoint should be configured with IPAM
        """
        return pulumi.get(self, "enable_ipam")

    @enable_ipam.setter
    def enable_ipam(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_ipam", value)

    @_builtins.property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the endpoint.
        """
        return pulumi.get(self, "endpoint_id")

    @endpoint_id.setter
    def endpoint_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint_id", value)

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Hostname of the endpoint.
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hostname", value)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IPv4 address on the network.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip", value)

    @_builtins.property
    @pulumi.getter(name="ipNet")
    def ip_net(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IP with the given mask within the private subnet
        """
        return pulumi.get(self, "ip_net")

    @ip_net.setter
    def ip_net(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip_net", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Database Instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Port in the Private Network.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The zone you want to attach the resource to
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


if not MYPY:
    class InstanceReadReplicaArgsDict(TypedDict):
        ip: NotRequired[pulumi.Input[_builtins.str]]
        """
        IPv4 address on the network.
        """
        name: NotRequired[pulumi.Input[_builtins.str]]
        """
        The name of the Database Instance.
        """
        port: NotRequired[pulumi.Input[_builtins.int]]
        """
        Port in the Private Network.
        """
elif False:
    InstanceReadReplicaArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceReadReplicaArgs:
    def __init__(__self__, *,
                 ip: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.str] ip: IPv4 address on the network.
        :param pulumi.Input[_builtins.str] name: The name of the Database Instance.
        :param pulumi.Input[_builtins.int] port: Port in the Private Network.
        """
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IPv4 address on the network.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Database Instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Port in the Private Network.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)


if not MYPY:
    class InstanceUpgradableVersionArgsDict(TypedDict):
        id: NotRequired[pulumi.Input[_builtins.str]]
        """
        Version ID to use in upgrade requests.
        """
        minor_version: NotRequired[pulumi.Input[_builtins.str]]
        """
        Minor version string (e.g., `15.5.0`).
        """
        name: NotRequired[pulumi.Input[_builtins.str]]
        """
        The name of the Database Instance.
        """
        version: NotRequired[pulumi.Input[_builtins.str]]
        """
        Version string (e.g., `15.5`).
        """
elif False:
    InstanceUpgradableVersionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceUpgradableVersionArgs:
    def __init__(__self__, *,
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 minor_version: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] id: Version ID to use in upgrade requests.
        :param pulumi.Input[_builtins.str] minor_version: Minor version string (e.g., `15.5.0`).
        :param pulumi.Input[_builtins.str] name: The name of the Database Instance.
        :param pulumi.Input[_builtins.str] version: Version string (e.g., `15.5`).
        """
        if id is not None:
            pulumi.set(__self__, "id", id)
        if minor_version is not None:
            pulumi.set(__self__, "minor_version", minor_version)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Version ID to use in upgrade requests.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter(name="minorVersion")
    def minor_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Minor version string (e.g., `15.5.0`).
        """
        return pulumi.get(self, "minor_version")

    @minor_version.setter
    def minor_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "minor_version", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Database Instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Version string (e.g., `15.5`).
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version", value)


if not MYPY:
    class ReadReplicaDirectAccessArgsDict(TypedDict):
        endpoint_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the endpoint of the Read Replica.
        """
        hostname: NotRequired[pulumi.Input[_builtins.str]]
        """
        Hostname of the endpoint. Only one of IP and hostname may be set.
        """
        ip: NotRequired[pulumi.Input[_builtins.str]]
        """
        IPv4 address of the endpoint (IP address). Only one of IP and hostname may be set.
        """
        name: NotRequired[pulumi.Input[_builtins.str]]
        """
        Name of the endpoint.
        """
        port: NotRequired[pulumi.Input[_builtins.int]]
        """
        TCP port of the endpoint.
        """
elif False:
    ReadReplicaDirectAccessArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ReadReplicaDirectAccessArgs:
    def __init__(__self__, *,
                 endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 ip: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.str] endpoint_id: The ID of the endpoint of the Read Replica.
        :param pulumi.Input[_builtins.str] hostname: Hostname of the endpoint. Only one of IP and hostname may be set.
        :param pulumi.Input[_builtins.str] ip: IPv4 address of the endpoint (IP address). Only one of IP and hostname may be set.
        :param pulumi.Input[_builtins.str] name: Name of the endpoint.
        :param pulumi.Input[_builtins.int] port: TCP port of the endpoint.
        """
        if endpoint_id is not None:
            pulumi.set(__self__, "endpoint_id", endpoint_id)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the endpoint of the Read Replica.
        """
        return pulumi.get(self, "endpoint_id")

    @endpoint_id.setter
    def endpoint_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint_id", value)

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Hostname of the endpoint. Only one of IP and hostname may be set.
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hostname", value)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IPv4 address of the endpoint (IP address). Only one of IP and hostname may be set.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the endpoint.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        TCP port of the endpoint.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)


if not MYPY:
    class ReadReplicaPrivateNetworkArgsDict(TypedDict):
        private_network_id: pulumi.Input[_builtins.str]
        """
        UUID of the Private Netork to be connected to the Read Replica.
        """
        enable_ipam: NotRequired[pulumi.Input[_builtins.bool]]
        """
        If true, the IP network address within the private subnet is determined by the IP Address Management (IPAM) service.

        > **Important:** One of `service_ip` or `enable_ipam=true` must be set.
        """
        endpoint_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the endpoint of the Read Replica.
        """
        hostname: NotRequired[pulumi.Input[_builtins.str]]
        """
        Hostname of the endpoint. Only one of IP and hostname may be set.
        """
        ip: NotRequired[pulumi.Input[_builtins.str]]
        """
        IPv4 address of the endpoint (IP address). Only one of IP and hostname may be set.
        """
        name: NotRequired[pulumi.Input[_builtins.str]]
        """
        Name of the endpoint.
        """
        port: NotRequired[pulumi.Input[_builtins.int]]
        """
        TCP port of the endpoint.
        """
        service_ip: NotRequired[pulumi.Input[_builtins.str]]
        """
        The IP network address within the private subnet. This must be an IPv4 address with a CIDR notation. If not set, The IP network address within the private subnet is determined by the IP Address Management (IPAM) service.
        """
        zone: NotRequired[pulumi.Input[_builtins.str]]
        """
        Private network zone
        """
elif False:
    ReadReplicaPrivateNetworkArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ReadReplicaPrivateNetworkArgs:
    def __init__(__self__, *,
                 private_network_id: pulumi.Input[_builtins.str],
                 enable_ipam: Optional[pulumi.Input[_builtins.bool]] = None,
                 endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 ip: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 service_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] private_network_id: UUID of the Private Netork to be connected to the Read Replica.
        :param pulumi.Input[_builtins.bool] enable_ipam: If true, the IP network address within the private subnet is determined by the IP Address Management (IPAM) service.
               
               > **Important:** One of `service_ip` or `enable_ipam=true` must be set.
        :param pulumi.Input[_builtins.str] endpoint_id: The ID of the endpoint of the Read Replica.
        :param pulumi.Input[_builtins.str] hostname: Hostname of the endpoint. Only one of IP and hostname may be set.
        :param pulumi.Input[_builtins.str] ip: IPv4 address of the endpoint (IP address). Only one of IP and hostname may be set.
        :param pulumi.Input[_builtins.str] name: Name of the endpoint.
        :param pulumi.Input[_builtins.int] port: TCP port of the endpoint.
        :param pulumi.Input[_builtins.str] service_ip: The IP network address within the private subnet. This must be an IPv4 address with a CIDR notation. If not set, The IP network address within the private subnet is determined by the IP Address Management (IPAM) service.
        :param pulumi.Input[_builtins.str] zone: Private network zone
        """
        pulumi.set(__self__, "private_network_id", private_network_id)
        if enable_ipam is not None:
            pulumi.set(__self__, "enable_ipam", enable_ipam)
        if endpoint_id is not None:
            pulumi.set(__self__, "endpoint_id", endpoint_id)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if service_ip is not None:
            pulumi.set(__self__, "service_ip", service_ip)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> pulumi.Input[_builtins.str]:
        """
        UUID of the Private Netork to be connected to the Read Replica.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "private_network_id", value)

    @_builtins.property
    @pulumi.getter(name="enableIpam")
    def enable_ipam(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, the IP network address within the private subnet is determined by the IP Address Management (IPAM) service.

        > **Important:** One of `service_ip` or `enable_ipam=true` must be set.
        """
        return pulumi.get(self, "enable_ipam")

    @enable_ipam.setter
    def enable_ipam(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_ipam", value)

    @_builtins.property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the endpoint of the Read Replica.
        """
        return pulumi.get(self, "endpoint_id")

    @endpoint_id.setter
    def endpoint_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint_id", value)

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Hostname of the endpoint. Only one of IP and hostname may be set.
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hostname", value)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IPv4 address of the endpoint (IP address). Only one of IP and hostname may be set.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the endpoint.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        TCP port of the endpoint.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter(name="serviceIp")
    def service_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IP network address within the private subnet. This must be an IPv4 address with a CIDR notation. If not set, The IP network address within the private subnet is determined by the IP Address Management (IPAM) service.
        """
        return pulumi.get(self, "service_ip")

    @service_ip.setter
    def service_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_ip", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Private network zone
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


